@@ -1,12 +1,13 @@
 import numpy as np
 import pandas as pd
-from matplotlib import pyplot as plt, rcParams, rcParamsDefault, spines, gridspec, patches
+from matplotlib import pyplot as plt, rcParams, rcParamsDefault, spines, gridspec, patches, colors, cm
 from scipy.interpolate import interp1d
 from sys import exit
 
 from .tools import label_decomposition, kinematic_component_labelling
 from .model import c_KMpS, gaussian_model, linear_model
 from .io import PdfMaker
+from astropy.wcs import WCS
 
 STANDARD_PLOT = {'figure.figsize': (12, 5),
                  'axes.titlesize': 12,
@@ -557,3 +558,151 @@ class LiMePlots:
 
         return
 
+
+class CubeInspector:
+
+    """
+    This class produces an interative matplotlib window for the muse data cubes. On the left axis with the cube slice
+    image you can right click a voxel for its corresponding spectrum to be plotted on the right axis.
+    """
+
+    def __init__(self, wavelength_array, cube_flux, image_bg, image_fg=None, contour_levels_fg=None,
+                 init_coord=None, header=None, fig_conf=None, axes_conf={}, min_bg_percentil=60):
+
+        self.fig = None
+        self.ax0, self.ax1, self.in_ax = None, None, None
+        self.grid_mesh = None
+        self.cube_flux = cube_flux
+        self.wave = wavelength_array
+        self.header = header
+        self.image_bg = image_bg
+        self.image_fg = image_fg
+        self.contour_levels_fg = contour_levels_fg
+        self.fig_conf = STANDARD_PLOT.copy()
+        self.axes_conf = {}
+        self.axlim_dict = {}
+        self.min_bg_percentil = min_bg_percentil
+
+        # Read the figure configuration
+        self.fig_conf = STANDARD_PLOT if fig_conf is None else fig_conf
+        rcParams.update(self.fig_conf)
+
+        # Read the axes format
+        if 'image' in axes_conf:
+            default_conf = {'xlabel': r'RA', 'ylabel': r'DEC', 'title': f'Cube flux slice'}
+            default_conf.update(axes_conf['image'])
+            self.axes_conf['image'] = default_conf
+        else:
+            self.axes_conf['image'] = {'xlabel': r'RA', 'ylabel': r'DEC', 'title': f'Cube flux slice'}
+
+        if 'spectrum' in axes_conf:
+            self.axes_conf['spectrum'] = STANDARD_AXES.update(axes_conf['spectrum'])
+        else:
+            self.axes_conf['spectrum'] = STANDARD_AXES
+
+        # Figure structure
+        self.fig = plt.figure(figsize=(18, 5))
+        gs = gridspec.GridSpec(nrows=1, ncols=2, figure=self.fig, width_ratios=[1, 2], height_ratios=[1])
+        self.fig.canvas.mpl_connect('button_press_event', self.on_click)
+        self.fig.canvas.mpl_connect('axes_enter_event', self.on_enter_axes)
+
+        # Axes configuration
+        if self.header is None:
+            self.ax0 = self.fig.add_subplot(gs[0])
+        else:
+            sky_wcs = WCS(self.header)
+            self.ax0 = self.fig.add_subplot(gs[0], projection=sky_wcs, slices=('x', 'y', 1))
+        self.ax1 = self.fig.add_subplot(gs[1])
+
+        # Image mesh grid
+        frame_size = self.cube_flux.shape
+        y, x = np.arange(0, frame_size[1]), np.arange(0, frame_size[2])
+        self.grid_mesh = np.meshgrid(x, y)
+
+        # If not central coord is provided use the middle point
+        if init_coord is None:
+            init_coord = int(self.cube_flux.shape[1]/2), int(self.cube_flux.shape[2]/2)
+
+        # Generate the plot
+        self.plot_map_voxel(self.image_bg, init_coord, self.image_fg, self.contour_levels_fg)
+        plt.show()
+
+        return
+
+    def plot_map_voxel(self, image_bg, voxel_coord=None, image_fg=None, flux_levels=None):
+
+        min_flux = np.nanpercentile(image_bg, self.min_bg_percentil)
+        norm_color_bg = colors.SymLogNorm(linthresh=min_flux,
+                                          vmin=min_flux,
+                                          base=10)
+        self.ax0.imshow(image_bg, cmap=cm.gray, norm=norm_color_bg)
+
+        # Emphasize input coordinate
+        if voxel_coord is not None:
+            idx_j, idx_i = voxel_coord
+            self.ax0.plot(idx_i, idx_j, '+', color='red')
+
+        # Plot contours image
+        if image_fg is not None:
+            self.ax0.contour(self.grid_mesh[0], self.grid_mesh[1], image_fg, cmap='viridis', levels=flux_levels,
+                             norm=colors.LogNorm())
+
+        # Voxel spectrum
+        if voxel_coord is not None:
+            idx_j, idx_i = voxel_coord
+            flux_voxel = self.cube_flux[:, idx_j, idx_i]
+            self.ax1.step(self.wave, flux_voxel)
+
+        self.axes_conf['spectrum']['title'] = f'Voxel {idx_j} - {idx_i}'
+
+        # Update the axis
+        self.ax0.update(self.axes_conf['image'])
+        self.ax1.update(self.axes_conf['spectrum'])
+
+        return
+
+    def on_click(self, event, mouse_trigger_buttton=3):
+
+        """
+        This method defines launches the new plot selection once the user clicks on an image voxel. By default this is a
+        a right click on a minimum three button mouse
+        :param event: This variable represents the user action on the plot
+        :param mouse_trigger_buttton: Number-coded mouse button which defines the button launching the voxel selection
+        :return:
+        """
+
+        if self.in_ax == self.ax0:
+
+            if event.button == mouse_trigger_buttton:
+
+                # Save axes zoom
+                self.save_zoom()
+
+                # Save clicked coordinates for next plot
+                idx_j, idx_i = np.rint(event.ydata).astype(int), np.rint(event.xdata).astype(int)
+                print(f'Current voxel: {idx_j}-{idx_i} (mouse button {event.button})')
+
+                # Remake the drawing
+                self.ax0.clear()
+                self.ax1.clear()
+                self.plot_map_voxel(self.image_bg, (idx_j, idx_i), self.image_fg, self.contour_levels_fg)
+
+                # Reset the image
+                self.reset_zoom()
+                self.fig.canvas.draw()
+
+    def on_enter_axes(self, event):
+        self.in_ax = event.inaxes
+
+    def save_zoom(self):
+        self.axlim_dict['image_xlim'] = self.ax0.get_xlim()
+        self.axlim_dict['image_ylim'] = self.ax0.get_ylim()
+        self.axlim_dict['spec_xlim'] = self.ax1.get_xlim()
+        self.axlim_dict['spec_ylim'] = self.ax1.get_ylim()
+
+    def reset_zoom(self):
+        self.ax0.set_xlim(self.axlim_dict['image_xlim'])
+        self.ax0.set_ylim(self.axlim_dict['image_ylim'])
+        self.ax1.set_xlim(self.axlim_dict['spec_xlim'])
+        self.ax1.set_ylim(self.axlim_dict['spec_ylim'])
+
